"""
Testing non-interactive feature extraction functions
"""

import os
import sys
sys.path.append('./src/')


from fusion_tools.handler import DSAHandler
from fusion_tools.tileserver import DSATileServer 
from fusion_tools.feature_extraction import (
    ParallelFeatureExtractor, distance_transform_features, color_features,
    texture_features, morphological_features, relative_distance, threshold_channels
)


def main():

    # Grabbing first item from demo DSA instance
    base_url = 'http://ec2-3-230-122-132.compute-1.amazonaws.com:8080/api/v1'
    item_id = '64f545302d82d04be3e39eec'

    # Starting visualization session
    tile_server = DSATileServer(
        api_url = base_url,
        item_id = item_id
    )

    # Starting the DSAHandler to grab information:
    dsa_handler = DSAHandler(
        girderApiUrl = base_url
    )

    print('Getting annotations')
    annotations = dsa_handler.get_annotations(
        item = item_id
    )

    print([f'{a["properties"]["name"]}: {len(a["features"])}' for a in annotations])
    
    feature_extractor = ParallelFeatureExtractor(
        image_source = tile_server,
        feature_list = [
            lambda image,mask,coords: distance_transform_features(image,mask,coords),
            lambda image,mask,coords: color_features(image,mask,coords),
            lambda image,mask,coords: texture_features(image,mask,coords),
            lambda image,mask,coords: morphological_features(image,mask,coords)
        ],
        preprocess = None,
        n_jobs = 4,
        verbose = True
    )

    feature_df = feature_extractor.start(annotations[0]['features'])

    print(feature_df)
    feature_df.to_csv('.\\tests\\test_features.csv')







if __name__=='__main__':
    main()




import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="fusion-tools",
    version="1.1.1",
    author="Sam Border",
    author_email="sam.border2256@gmail.com",
    description="Modular visualization and analysis dashboard creation for high-resolution microscopy images",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/spborder/fusion-tools",
    install_requires=[
        "lxml>=4.9.2",
        "geojson>=3.0.1",
        "shapely>=2.0.1",
        "geopandas",
        "girder-client",
        "numpy>=1.20.0",
        "large-image[common]",
        "wsi-annotations-kit",
        "dash-leaflet[all]>=1.0.15",
        "dash-extensions",
        "dash-bootstrap-components",
        "dash-mantine-components>=0.14.4",
        "dash-treeview-antd",
        "requests",
        "uuid",
        "scikit-image",
        "umap-learn",
        "fastapi>=0.103.2",
        "uvicorn",
        "statsmodels",
        "typing-extensions>=4.8.0"
    ],
    packages=setuptools.find_packages(where = 'src',include=["fusion_tools*"]),
    package_dir={"":"src"},
    classifiers=[
        "Development Status :: 4 - Beta",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
)